@echo off

setlocal

@rem ----------------------------------------------------------------------
@rem  findJar.bat -- try to find the path to a specified jar
@rem
@rem  stdout:     echoes jar path or "ERROR" to standard output
@rem  console:    echoes error message (if any) to console
@rem  errorlevel: returns 0 if jar found, 1 if not found
@rem
@rem  (C) Copyright IBM Corp. 2005 All Rights Reserved.
@rem
@rem  US Government Users Restricted Rights - Use, duplication or
@rem  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
@rem ----------------------------------------------------------------------


@rem :
@rem : Determine where this script is installed
@rem :

set THIS_CMD_PATH=%~f0

set THIS_CMD_DIR=%THIS_CMD_PATH:\findJar.bat=%


@rem :
@rem : Make sure the user specified which jar they want
@rem :

set JAR_TO_FIND=%1

if "%JAR_TO_FIND%" == "" @echo Please specify a jar to find. > con
if "%JAR_TO_FIND%" == "" goto notFound


@rem :
@rem : If current dir ends in 'bin', we're on an endpoint
@rem : and we'll check for jars in .\lib and other locations
@rem :

set CMD_DIR_PARENT=%THIS_CMD_DIR:\bin=%

if not "%THIS_CMD_DIR%" == "%CMD_DIR_PARENT%\bin" goto endEndpoint

set JARPATH=%CMD_DIR_PARENT%\lib
if exist "%JARPATH%\%JAR_TO_FIND%" goto foundjar

set JARPATH=%CMD_DIR_PARENT%\app\instrument\60\lib
if exist "%JARPATH%\%JAR_TO_FIND%" goto foundjar

set JARPATH=%CMD_DIR_PARENT%\app\instrument\60\lib\ext
if exist "%JARPATH%\%JAR_TO_FIND%" goto foundjar

goto notFound

:endEndpoint


@rem :
@rem : If current dir ends in 'scripts' and 'isCluster.bat'
@rem : exists, we're on a clustered MS and we'll check for
@rem : jars in .\scripts\cli\lib.
@rem :

set CMD_DIR_PARENT=%THIS_CMD_DIR:\scripts=%

if not "%THIS_CMD_DIR%" == "%CMD_DIR_PARENT%\scripts" goto endClusterMS

if not exist "%THIS_CMD_DIR%\isCluster.bat" goto endClusterMS

set JARPATH=%CMD_DIR_PARENT%\scripts\cli\lib
if exist "%JARPATH%\%JAR_TO_FIND%" goto foundjar

goto notFound

:endClusterMS


@rem :
@rem : If current dir ends in 'scripts', we're on a standalone MS
@rem : and we'll check for jars in .\ITMTP.ear and other locations
@rem :

set CMD_DIR_PARENT=%THIS_CMD_DIR:\scripts=%

if not "%THIS_CMD_DIR%" == "%CMD_DIR_PARENT%\scripts" goto endStandaloneMS

set JARPATH=%CMD_DIR_PARENT%\ITMTP.ear
if exist "%JARPATH%\%JAR_TO_FIND%" goto foundjar

set JARPATH=%CMD_DIR_PARENT%\lib
if exist "%JARPATH%\%JAR_TO_FIND%" goto foundjar

set JARPATH=%CMD_DIR_PARENT%\downloads\cli\lib
if exist "%JARPATH%\%JAR_TO_FIND%" goto foundjar

set JARPATH=%CMD_DIR_PARENT%\scripts\cli\lib
if exist "%JARPATH%\%JAR_TO_FIND%" goto foundjar

set JARPATH=%CMD_DIR_PARENT%\scripts\logviewer
if exist "%JARPATH%\%JAR_TO_FIND%" goto foundjar

goto notFound

:endStandaloneMS


@rem :
@rem : Give up if we aren't in a normal location
@rem :

@echo Cannot determine path to jar files. Current location does not > con
@echo appear to be an valid ITCAM management server or endpoint.    > con
goto notFound

:endBadInstall


@rem :
@rem : Couldn't find jar. Echo "ERROR" to stdout, an error message to console
@rem : and return a failure code
@rem :

:notfound

if not "%JAR_TO_FIND%" == "" @echo Cannot find path to jar '%JAR_TO_FIND%' > con
@echo ERROR
endlocal
exit /B 1


@rem :
@rem : We found it, echo the location to stdout and return a success code
@rem :

:foundjar

@echo %JARPATH%\%JAR_TO_FIND%
endlocal
exit /B 0


@rem ----------------------------------------------------------------------
@rem End script
@rem ----------------------------------------------------------------------
