# ----------------------------------------------------------------------
#  findJar.sh -- try to find the path to a specified jar
#
#  output:
#      stdout:  echoes jar path to stdout
#      stderr:  echoes error message (if any) to stderr
#      return:  0 if jar found, 1 if not found
# 
#  (C) Copyright IBM Corp. 2005 All Rights Reserved.
#  
#  US Government Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# ----------------------------------------------------------------------

# Note: if-tests must use 'test' syntax instead of '['
#       in order to work under OS/400 qsh.


# Determine where this script is installed

case "$0" in
  /*)   THIS_CMD_PATH="$0"       ;;
   *)   THIS_CMD_PATH="`pwd`/$0" ;;
esac

THIS_CMD_DIR="`dirname $THIS_CMD_PATH`"
THIS_CMD_DIR=`(cd "$THIS_CMD_DIR" 2>/dev/null && pwd)`

CMD_DIR_PARENT=`(cd "$THIS_CMD_DIR/.." 2>/dev/null && pwd)`


# Make sure the user specified which jar they want

JAR_TO_FIND=$1

if test "$JAR_TO_FIND" = "" ; then
  echo Please specify a jar to find. 1>&2
  exit 1
fi


# If current dir ends in 'bin', we're on an endpoint
# and we'll check for jars in ./lib and other locations

if test "$THIS_CMD_DIR" = "$CMD_DIR_PARENT/bin" ; then

  for jlib in "$CMD_DIR_PARENT/lib"                       \
              "$CMD_DIR_PARENT/app/instrument/60/lib"     \
              "$CMD_DIR_PARENT/app/instrument/60/lib/ext"
  do
    if test -f "$jlib/$JAR_TO_FIND" ; then
      echo "$jlib/$JAR_TO_FIND"
      exit 0
    fi
  done
  
  echo Cannot find path to jar $JAR_TO_FIND 1>&2
  exit 1

fi

# end endpoint


# If current dir ends in 'scripts' and 'isCluster.sh' exists,
# we're on a clustered management server and we'll check for
# jars in ./scripts/cli/lib.

if test "$THIS_CMD_DIR" = "$CMD_DIR_PARENT/scripts" ; then

  if test -f "$THIS_CMD_DIR/isCluster.sh" ; then

    for jlib in "$CMD_DIR_PARENT/scripts/cli/lib"
    do
      if test -f "$jlib/$JAR_TO_FIND" ; then
        echo "$jlib/$JAR_TO_FIND"
        exit 0
      fi
    done

    echo Cannot find path to jar $JAR_TO_FIND 1>&2
    exit 1

  fi
fi

# end cluster MS


# If current dir ends in 'scripts', we're on a standalone MS
# and we'll check for jars in ./ITMTP.ear and other locations

if test "$THIS_CMD_DIR" = "$CMD_DIR_PARENT/scripts" ; then

  for jlib in "$CMD_DIR_PARENT/ITMTP.ear"         \
              "$CMD_DIR_PARENT/lib"               \
              "$CMD_DIR_PARENT/downloads/cli/lib" \
              "$CMD_DIR_PARENT/scripts/cli/lib"   \
              "$CMD_DIR_PARENT/scripts/logviewer"
  do
    if test -f "$jlib/$JAR_TO_FIND" ; then
      echo "$jlib/$JAR_TO_FIND"
      exit 0
    fi
  done
  
  echo Cannot find path to jar $JAR_TO_FIND 1>&2
  exit 1

fi

# end standalone MS


# Give up if we aren't in a normal location

echo Cannot determine path to jar files. Current location does not 1>&2
echo appear to be an valid ITCAM management server or endpoint.    1>&2
exit 1

# end bad install


# ----------------------------------------------------------------------
# End script
# ----------------------------------------------------------------------
